<?php

namespace Feature;

use EventPortal\AuthPassword\Tests\TestCase;
use EventPortal\AuthPassword\Tests\User;
use Illuminate\Foundation\Testing\RefreshDatabase;

class LoginTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function user_cannot_login_with_invalid_credentials(): void
    {
        User::create([
            'email' => 'someone@example.com',
            'password' => bcrypt('Password1'),
        ]);

        $this->post(
            route('login.submit'),
            [
                config('auth-password.field_names.username') => 'someone@example.com',
                config('auth-password.field_names.password') => 'WRONG_PASSWORD',
            ]
        )
            ->assertSessionHasErrors([config('auth-password.field_names.password') => trans('auth.failed')]);
    }

    /** @test **/
    public function user_can_login(): void
    {
        $user = User::create([
            'email' => 'someone@example.com',
            'password' => bcrypt('Password1'),
        ]);

        $this->post(
            route('login.submit'),
            [
                config('auth-password.field_names.username') => 'someone@example.com',
                config('auth-password.field_names.password') => 'Password1',
            ]
        );
        $this->assertAuthenticatedAs($user);
    }

    /** @test **/
    public function user_is_redirected_to_home_route_after_login(): void
    {
        User::create([
            'email' => 'someone@example.com',
            'password' => bcrypt('Password1'),
        ]);

        $this->post(
            route('login.submit'),
            [
                config('auth-password.field_names.username') => 'someone@example.com',
                config('auth-password.field_names.password') => 'Password1',
            ]
        )->assertRedirect(route('test-route'));
    }
}
